# JGTPY Agent Guide

Welcome! This guide is designed for LLM-based agents. It explains the command line utilities shipped with **jgtpy** and how they work together.

## Sections
- [Overview](overview.md)
- [jgtcli](jgtcli.md)
- [cdscli](cdscli.md)
- [idscli](idscli.md)
- [adscli](adscli.md)
- [pds2cds](pds2cds.md)

